require 'test/unit'
require 'shoulda'

class NiceTest < Test::Unit::TestCase

  context "shoulda" do

    should 'just work' do
      # is this test runs at all it already works :)
      assert true
    end

  end
  
end
